import { json, csv } from 'd3';
import { feature } from 'topojson';

export const getData = () =>
	// Load Multiple Data Files
	Promise
		.all([
      csv('https://vizhub.com/curran/datasets/un-population-estimates-2017-medium-variant.csv'),
      json('https://unpkg.com/visionscarto-world-atlas@0.0.6/world/50m.json')
  	])
		.then(([csvData,topoJSONdata]) => {
      
      // Create Country Lookup data from tsv file
      const countryLkp = csvData.reduce((a, d) => {
        a[d['Country code']] = d;
        return a;
      }, {});
      
      // Create worldData from topoJSON file
      const worldData = feature(topoJSONdata,topoJSONdata.objects.countries).features;

      // Add Country Data to WorldData
      worldData.forEach( d => {
        Object.assign(d.properties, countryLkp[+d.id]);
      });
      
      // Add Population Data
      const populationData = worldData
      	.filter( d => d.properties['2018'])
      	.map( d => {
          d.properties['2018'] = +d.properties['2018'].replace(/ /g, '') * 1000;
          return d;
        });

      return {
        worldData: worldData,
        popData: populationData
      }
     
    }); 
