import {
  select,
  scaleOrdinal,
  schemeSpectral,
  zoom,
  event,
  scaleSqrt,
  max,
  format
} from 'd3';
import { getData } from './data';
import { circles } from './circles';
import { earthMap } from '/map';
import { sizeLegend } from '/legend';

// Get the SVG from the DOM
const svg = select('svg');

// Add Groups
const mainGroup =svg.append('g');

// Add zoom to the Main Group
svg.call(zoom().on('zoom', () => {
 mainGroup.attr('transform', event.transform);
}));

const sizeScale = scaleSqrt();
const sizeValue = d => d.properties['2018'];
const sizeFormat = format(',');

let mapData, popData;

// Render Function
const render = () => {

  // Render the Earth
	mainGroup
  	.call( earthMap, {
    	mapData,
    	sizeValue,
    	sizeFormat
  });
    
  // Render the Population Circles
	mainGroup
		.call( circles, {
			popData,
    	sizeScale,
    	sizeValue,
    	sizeFormat
	});  
 
  // Render the Legend
  svg
  	.call( sizeLegend, {
			sizeScale,
      xOff: 50,
    	yOff: 70,
  		itemAmount: 7,
   		itemSpacing: 70,
    	itemTextPos: 35,
    	tickFormat: sizeFormat
	}); 
};

getData()
  .then(data => {

    mapData = data.worldData;
    popData = data.popData;

  	// Calculate Circle Sizes based on population
	  sizeScale
    	.domain([0,max(popData,sizeValue)])
  		.range([0,33]);
 
  	// Render when the data is loaded
    render();
});