import {
  geoPath,
  geoNaturalEarth1
} from 'd3';

// Init Topographic Projection
const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

// Render the Color Legend
export const earthMap = (selection, props) => {
  // Deconstruct the props argument
  const {
    mapData,
    sizeValue,
    sizeFormat
  } = props;
  const earthGroup = selection.append('g');
  const gUpdate = earthGroup.selectAll('g').data([null]);
  const gEnter = gUpdate.enter().append('g');
  const g = gUpdate.merge(gEnter);
  
  // Add the Sphere / Ocean
  gEnter
    .append('path')
    	.attr('d', pathGenerator({type: 'Sphere'}))
    	.attr('class', 'ocean')
  	.merge(gUpdate.select('.ocean'))
  		.attr('opacity', 1);

  // Add the Countries
  const countryPaths = g.selectAll('.land')
    .data(mapData);
  const countryPathsEnter = countryPaths
    .enter().append('path')
    	.attr('class', d => d.properties['2018'] ? 'land' : 'landno')
      .attr('d', pathGenerator);
  countryPathsEnter
     .append('title')
       .text(d => isNaN(sizeValue(d))
          ? 'Missing Data'
          : [ d.properties['Region, subregion, country or area *'],sizeFormat(sizeValue(d))].join(': '));
  
}